@@ -11,6 +11,7 @@ import random
 from sklearn.model_selection import train_test_split, GridSearchCV
 from sklearn.metrics import confusion_matrix
 import xgboost as xgb
+import shap
 
 RAND_STATE = 42
 
@@ -162,7 +163,7 @@ def plot_inverse_mapping(reducer,umap_df):
     
     return None
 
-def plot_shap_summary(explainer,umap_df):
+def plot_shap_summary(explainer,umap_df,colors):
     shap_values = explainer.shap_values(umap_df['waveform'].tolist())
     class_inds = np.argsort([-np.abs(shap_values[i]).mean() for i in range(len(shap_values))])
     shap_cmap = ListedColormap(np.array(colors)[class_inds])
